==> gql-0.5.0.tar.gz: lib/src/type_system/type.dart <==
import "package:meta/meta.dart";

class Schema {
  Object queryType;
  Object mutationType;
  Object subscriptionType;

  Iterable<Type> types;
  Iterable<Directive> directives;

  Iterable<AppliedDirective> appliedDirectives;

  Schema({
    this.types,
    this.queryType,
    this.mutationType,
    this.subscriptionType,
    this.directives,
  });
}

enum DirectiveLocation {
  query,
  mutation,
  subscription,
  field,
  fragmentDefinition,
  fragmentSpread,
  inlineFragment,
  schema,
  scalar,
  object,
  fieldDefinition,
  argumentDefinition,
  interface,
  union,
  enumDefinition,
  enumValue,
  inputObject,
  inputFieldDefinition,
}

abstract class Base {
  String name;
  String description;

  Iterable<AppliedDirective> appliedDirectives;

  Base({
    @required this.name,
    @required this.description,
    @required this.appliedDirectives,
  });
}

class InputValue extends Base {
  Type type;
  String defaultValue;

  InputValue({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.type,
    this.defaultValue,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Field extends Base {
  Iterable<InputValue> args;
  Type type;

  Field({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.args,
    this.type,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Directive extends Base {
  Iterable<DirectiveLocation> locations;
  Iterable<InputValue> args;

  Directive({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.locations,
    this.args,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

abstract class Type extends Base {
  Type({
    @required String name,
    @required String description,
    @required Iterable<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Object extends Type {
  Iterable<Field> fields;
  Iterable<Interface> interfaces;

  Object({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.fields,
    this.interfaces,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Interface extends Type {
  Iterable<Field> fields;
  Iterable<Type> possibleTypes;

  Interface({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.fields,
    this.possibleTypes,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Union extends Type {
  Iterable<Type> possibleTypes;

  Union({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.possibleTypes,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Enum extends Type {
  Iterable<EnumValue> enumValues;

  Enum({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.enumValues,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class EnumValue extends Base {
  EnumValue({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class InputObject extends Type {
  Iterable<InputValue> inputValues;

  InputObject({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    this.inputValues,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

abstract class WrappedType<T extends Type> extends Type {
  T ofType;

  WrappedType({
    @required String name,
    @required String description,
    @required Iterable<AppliedDirective> appliedDirectives,
    @required this.ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class NonNull<T extends Type> extends WrappedType<T> {
  NonNull({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    T ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
          ofType: ofType,
        );
}

class List<T extends Type> extends WrappedType<T> {
  List({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
    T ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
          ofType: ofType,
        );
}

class Scalar extends Type {
  Scalar({
    String name,
    String description,
    Iterable<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class AppliedDirective {
  Directive directive;
  Iterable<AppliedDirectiveArgument> args;

  AppliedDirective({
    this.directive,
    this.args,
  });
}

class AppliedDirectiveArgument {
  String name;
  String value;

  AppliedDirectiveArgument({
    this.name,
    this.value,
  });
}

==> gql-0.8.3.tar.gz: lib/src/type_system/type.dart <==
import "dart:core" as core;
import "package:meta/meta.dart";

class Schema {
  Object queryType;
  Object mutationType;
  Object subscriptionType;

  core.List<Type> types;
  core.List<Directive> directives;

  core.List<AppliedDirective> appliedDirectives;

  Schema({
    this.types,
    this.queryType,
    this.mutationType,
    this.subscriptionType,
    this.directives,
  });
}

enum DirectiveLocation {
  query,
  mutation,
  subscription,
  field,
  fragmentDefinition,
  fragmentSpread,
  inlineFragment,
  schema,
  scalar,
  object,
  fieldDefinition,
  argumentDefinition,
  interface,
  union,
  enumDefinition,
  enumValue,
  inputObject,
  inputFieldDefinition,
}

abstract class Base {
  core.String name;
  core.String description;

  core.List<AppliedDirective> appliedDirectives;

  Base({
    @required this.name,
    @required this.description,
    @required this.appliedDirectives,
  });
}

class InputValue extends Base {
  Type type;
  core.String defaultValue;

  InputValue({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.type,
    this.defaultValue,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Field extends Base {
  core.List<InputValue> args;
  Type type;

  Field({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.args,
    this.type,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Directive extends Base {
  core.List<DirectiveLocation> locations;
  core.List<InputValue> args;

  Directive({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.locations,
    this.args,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

abstract class Type extends Base {
  Type({
    @required core.String name,
    @required core.String description,
    core.List<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Object extends Type {
  core.List<Field> fields;
  core.List<Interface> interfaces;

  Object({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.fields,
    this.interfaces,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Interface extends Type {
  core.List<Field> fields;
  core.List<Type> possibleTypes;

  Interface({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.fields,
    this.possibleTypes,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Union extends Type {
  core.List<Type> possibleTypes;

  Union({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.possibleTypes,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class Enum extends Type {
  core.List<EnumValue> enumValues;

  Enum({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.enumValues,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class EnumValue extends Base {
  EnumValue({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class InputObject extends Type {
  core.List<InputValue> inputValues;

  InputObject({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    this.inputValues,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

abstract class WrappedType<T extends Type> extends Type {
  T ofType;

  WrappedType({
    @required core.String name,
    @required core.String description,
    core.List<AppliedDirective> appliedDirectives,
    @required this.ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class NonNull<T extends Type> extends WrappedType<T> {
  NonNull({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    T ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
          ofType: ofType,
        );
}

class List<T extends Type> extends WrappedType<T> {
  List({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
    T ofType,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
          ofType: ofType,
        );
}

class Scalar extends Type {
  Scalar({
    core.String name,
    core.String description,
    core.List<AppliedDirective> appliedDirectives,
  }) : super(
          name: name,
          description: description,
          appliedDirectives: appliedDirectives,
        );
}

class AppliedDirective {
  Directive directive;
  core.List<AppliedDirectiveArgument> args;

  AppliedDirective({
    this.directive,
    this.args,
  });
}

class AppliedDirectiveArgument {
  core.String name;
  core.String value;

  AppliedDirectiveArgument({
    this.name,
    this.value,
  });
}
